@@ -7,6 +7,7 @@ import shutil
 import subprocess
 import click
 import tempfile
+import time
 
 from binstar_client.utils import get_server_api
 import binstar_client.errors
@@ -135,14 +136,16 @@ def upload_or_check(recipe_dir, owner, channel, variant):
 
     # This is the actual fix where we create the token file once and reuse it for all uploads
     if token:
-      with get_temp_token(cli.token) as token_fn:
-        for path in new_distributions:
-            upload(token_fn, path, owner, channel)
-            print('Uploaded {}'.format(path))
+        with get_temp_token(cli.token) as token_fn:
+            for path in new_distributions:
+                upload(token_fn, path, owner, channel)
+                print('Uploaded {}'.format(path))
+        return True
     else:
-      for path in new_distributions:
-          print("Distribution {} is new for {}, but no upload is taking place "
+        for path in new_distributions:
+            print("Distribution {} is new for {}, but no upload is taking place "
                 "because the BINSTAR_TOKEN is missing.".format(path, owner))
+        return False
 
 
 @click.command()
@@ -160,7 +163,17 @@ def main(recipe_dir, owner, channel, variant):
     Upload or check consistency of a built version of a conda recipe with binstar.
     Note: The existence of the BINSTAR_TOKEN environment variable determines
     whether the upload should actually take place."""
-    upload_or_check(recipe_dir, owner, channel, variant)
+    
+    # perform a backoff in case we fail.  THis should limit the failures from
+    # issues with the Anaconda api
+    for i in range(1, 10):
+        try:
+            res = upload_or_check(recipe_dir, owner, channel, variant)
+            return res
+        except Exception as e:
+            timeout = i ** 2
+            print("Failed to upload due to {}.  Trying again in {} seconds".format(e, timeout))
+            time.sleep(timeout)
 
 
 if __name__ == '__main__':
